==> pw-iso20022-SRU2022-10.0.1-sources.jar: com/prowidesoftware/swift/model/mx/dic/SingleOrMassQuote2Choice.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Choice between a single or a mass quote.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SingleOrMassQuote2Choice", propOrder = {
    "snglQtDtls",
    "massQtDtls"
})
public class SingleOrMassQuote2Choice {

    @XmlElement(name = "SnglQtDtls")
    protected SingleQuote1 snglQtDtls;
    @XmlElement(name = "MassQtDtls")
    protected QuoteStatus2 massQtDtls;

    /**
     * Gets the value of the snglQtDtls property.
     * 
     * @return
     *     possible object is
     *     {@link SingleQuote1 }
     *     
     */
    public SingleQuote1 getSnglQtDtls() {
        return snglQtDtls;
    }

    /**
     * Sets the value of the snglQtDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link SingleQuote1 }
     *     
     */
    public SingleOrMassQuote2Choice setSnglQtDtls(SingleQuote1 value) {
        this.snglQtDtls = value;
        return this;
    }

    /**
     * Gets the value of the massQtDtls property.
     * 
     * @return
     *     possible object is
     *     {@link QuoteStatus2 }
     *     
     */
    public QuoteStatus2 getMassQtDtls() {
        return massQtDtls;
    }

    /**
     * Sets the value of the massQtDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link QuoteStatus2 }
     *     
     */
    public SingleOrMassQuote2Choice setMassQtDtls(QuoteStatus2 value) {
        this.massQtDtls = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2023-9.4.7-sources.jar: com/prowidesoftware/swift/model/mx/dic/SingleOrMassQuote2Choice.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Choice between a single or a mass quote.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SingleOrMassQuote2Choice", propOrder = {
    "snglQtDtls",
    "massQtDtls"
})
public class SingleOrMassQuote2Choice {

    @XmlElement(name = "SnglQtDtls")
    protected SingleQuote1 snglQtDtls;
    @XmlElement(name = "MassQtDtls")
    protected QuoteStatus2 massQtDtls;

    /**
     * Gets the value of the snglQtDtls property.
     * 
     * @return
     *     possible object is
     *     {@link SingleQuote1 }
     *     
     */
    public SingleQuote1 getSnglQtDtls() {
        return snglQtDtls;
    }

    /**
     * Sets the value of the snglQtDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link SingleQuote1 }
     *     
     */
    public SingleOrMassQuote2Choice setSnglQtDtls(SingleQuote1 value) {
        this.snglQtDtls = value;
        return this;
    }

    /**
     * Gets the value of the massQtDtls property.
     * 
     * @return
     *     possible object is
     *     {@link QuoteStatus2 }
     *     
     */
    public QuoteStatus2 getMassQtDtls() {
        return massQtDtls;
    }

    /**
     * Sets the value of the massQtDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link QuoteStatus2 }
     *     
     */
    public SingleOrMassQuote2Choice setMassQtDtls(QuoteStatus2 value) {
        this.massQtDtls = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
